@@ -61,7 +61,7 @@ sub grep {
         sub {
             local $_ = bless { set => $_[0]->clone }, 'DateTime::Span';
             my $result = $callback->();
-            return $_ if $result;
+            return $_->{set} if $result && $_;
             return;
         }
     );
@@ -198,6 +198,11 @@ sub empty_set {
     return bless { set => Set::Infinite::_recurrence->new }, $class;
 }
 
+sub is_empty_set {
+    my $set = $_[0];
+    $set->{set}->is_null;
+}
+
 sub clone { 
     bless { 
         set => $_[0]->{set}->copy,
@@ -358,7 +363,7 @@ sub as_list {
     $set = $set->intersection( $span ) if $span;
 
     # Note: removing this line means we may end up in an infinite loop!
-    return undef if $set->{set}->is_too_complex;  # undef = no begin/end
+    return undef if $set->{set}->is_too_complex;  # undef = no start/end
 
     # return if $set->{set}->is_null;  # nothing = empty
     my @result;
@@ -497,14 +502,18 @@ sub complement {
     return $tmp;
 }
 
-sub min {
+sub start {
     return DateTime::Set::_fix_datetime( $_[0]->{set}->min );
 }
 
-sub max { 
+*min = \&start;
+
+sub end { 
     return DateTime::Set::_fix_datetime( $_[0]->{set}->max );
 }
 
+*max = \&end;
+
 # returns a DateTime::Span
 sub span { 
     my $set = $_[0]->{set}->span;
@@ -619,6 +628,12 @@ a span like C<[$dt, inf)>.
 
 Creates a new empty set.
 
+=item * is_empty_set
+
+Returns true is the set is empty; false otherwise.
+
+    print "nothing" if $set->is_empty_set;
+
 =item * clone
 
 This object method returns a replica of the given object.
@@ -635,13 +650,24 @@ the local time are made, except to account for leap seconds.  If the
 new time zone is floating, then the I<UTC> time is adjusted in order
 to leave the local time untouched.
 
-=item * min
 
-=item * max
+=item * start, min
+
+=item * end, max
+
+First or last dates in the set.
+
+It is possible that the return value from these methods may be a
+C<DateTime::Infinite::Future> or a C<DateTime::Infinite::Past> object.
+
+If the set ends C<before> a date C<$dt>, it returns C<$dt>. Note that
+in this case C<$dt> is not a set element - but it is a set boundary.
+
+These methods may return C<undef> if the set is empty.
+
+These methods return just a I<copy> of the actual boundary value.
+If you modify the result, the set will not be modified.
 
-First or last dates in the set.  These methods may return C<undef> if
-the set is empty.  It is also possible that these methods may return a
-scalar containing infinity or negative infinity.
 
 =item * duration
 
@@ -784,6 +810,10 @@ These set functions return a boolean value.
 These methods can accept a C<DateTime>, C<DateTime::Set>,
 C<DateTime::Span>, or C<DateTime::SpanSet> object as an argument.
 
+intersects() returns 1 for true, and 0 for false. In a few cases
+the algorithm can't decide if the sets intersect at all, and 
+intersects() will return C<undef>.
+
 =item * iterator / next / previous
 
 This method can be used to iterate over the spans in a set.
@@ -921,7 +951,7 @@ Please report bugs using rt.cpan.org
 
 =head1 AUTHOR
 
-Flavio Soibelmann Glock <fglock@pucrs.br>
+Flavio Soibelmann Glock <fglock@gmail.com>
 
 The API was developed together with Dave Rolsky and the DateTime Community.
 
